package com.ruoyi.powerdistribution.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.powerdistribution.mapper.PdmScoreRankTeamMapper;
import com.ruoyi.powerdistribution.domain.PdmScoreRankTeam;
import com.ruoyi.powerdistribution.service.IPdmScoreRankTeamService;

/**
 * 队伍积分排名Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-05
 */
@Service
public class PdmScoreRankTeamServiceImpl implements IPdmScoreRankTeamService
{
    @Autowired
    private PdmScoreRankTeamMapper pdmScoreRankTeamMapper;

    /**
     * 查询队伍积分排名
     *
     * @param id 队伍积分排名主键
     * @return 队伍积分排名
     */
    @Override
    public PdmScoreRankTeam selectPdmScoreRankTeamById(Long id)
    {
        return pdmScoreRankTeamMapper.selectPdmScoreRankTeamById(id);
    }

    /**
     * 查询队伍积分排名列表
     *
     * @param pdmScoreRankTeam 队伍积分排名
     * @return 队伍积分排名
     */
    @Override
    public List<PdmScoreRankTeam> selectPdmScoreRankTeamList(PdmScoreRankTeam pdmScoreRankTeam)
    {
        return pdmScoreRankTeamMapper.selectPdmScoreRankTeamList(pdmScoreRankTeam);
    }

    /**
     * 新增队伍积分排名
     *
     * @param pdmScoreRankTeam 队伍积分排名
     * @return 结果
     */
    @Override
    public int insertPdmScoreRankTeam(PdmScoreRankTeam pdmScoreRankTeam)
    {
        pdmScoreRankTeam.setCreateTime(DateUtils.getNowDate());
        return pdmScoreRankTeamMapper.insertPdmScoreRankTeam(pdmScoreRankTeam);
    }

    /**
     * 修改队伍积分排名
     *
     * @param pdmScoreRankTeam 队伍积分排名
     * @return 结果
     */
    @Override
    public int updatePdmScoreRankTeam(PdmScoreRankTeam pdmScoreRankTeam)
    {
        pdmScoreRankTeam.setUpdateTime(DateUtils.getNowDate());
        return pdmScoreRankTeamMapper.updatePdmScoreRankTeam(pdmScoreRankTeam);
    }

    /**
     * 批量删除队伍积分排名
     *
     * @param ids 需要删除的队伍积分排名主键
     * @return 结果
     */
    @Override
    public int deletePdmScoreRankTeamByIds(Long[] ids)
    {
        return pdmScoreRankTeamMapper.deletePdmScoreRankTeamByIds(ids);
    }

    /**
     * 删除队伍积分排名信息
     *
     * @param id 队伍积分排名主键
     * @return 结果
     */
    @Override
    public int deletePdmScoreRankTeamById(Long id)
    {
        return pdmScoreRankTeamMapper.deletePdmScoreRankTeamById(id);
    }
}
